@@ -94,6 +94,8 @@
 					break;
 					// track no
 				case 'n':
+          if ([track trackNumber] <= 9)
+            [filename appendString:@"0"];
 					[filename appendString:[NSString stringWithFormat:@"%d",[track trackNumber]]];
 					break;
 					// codec
@@ -185,8 +187,8 @@
 		[writeTag setDisplayStatus:NO];
 		
 		[tasks addObject:writeTag];
-		
-		[writeTag release];
+    
+    [writeTag release];
 	}
 	
 	if ([preferences iTunesIntegration])
@@ -549,7 +551,13 @@
 		// so we must use the filename extension to determine codec
 		 
 		Track *track = [[Track alloc] init];
-		[track setFullPath:[[NSURL URLWithString:[thisTrackDict valueForKey:@"Location"]] relativePath]];
+    NSString *location = [thisTrackDict valueForKey:@"Location"];
+    if (location == nil)
+    {
+      NSLog(@"location nil when reading in iTunes library! Ignoring entry");
+      break;
+    }
+		[track setFullPath:[[NSURL URLWithString:location] relativePath]];
 		[track fileTypeFromExtension];
 		
 		[track setTitle:[thisTrackDict valueForKey:@"Name"]];
