@@ -242,7 +242,7 @@
   else if ([extension compare:@"MP2" options:NSCaseInsensitiveSearch] == NSOrderedSame)
 		[self setFileType:LIBMTP_FILETYPE_MP2];
   else if ([extension compare:@"M4A" options:NSCaseInsensitiveSearch] == NSOrderedSame)
-		[self setFileType:LIBMTP_FILETYPE_M4A];
+		[self setFileType:LIBMTP_FILETYPE_AAC]; //AAC or M4A?
   else if ([extension compare:@"DOC" options:NSCaseInsensitiveSearch] == NSOrderedSame)
 		[self setFileType:LIBMTP_FILETYPE_DOC];
   else if ([extension compare:@"XML" options:NSCaseInsensitiveSearch] == NSOrderedSame)
