@@ -37,6 +37,8 @@
 	LIBMTP_mtpdevice_t *device;
 	uint16_t *supportedFiletypes;
 	uint16_t supportedFiletypesLength;
+  BOOL createAlbumFiles;
+  BOOL cancelCurrentTransaction;
 	
 	NSString *deviceString;
 	NSString *firmwareVersionString;
@@ -99,8 +101,16 @@
 - (BOOL)isSupportedFileType:(LIBMTP_filetype_t)type;
 - (void)downloadAlbumList;
 - (Album *)addTrack:(Track *)track ToAlbumWithName:(NSString *)albumName;
+- (void)setCreateAlbumFiles:(BOOL)newCreateAlbumFiles;
+- (void)cancelCurrentTransaction;
 
 int progress (u_int64_t sent, u_int64_t total, const char* buf, unsigned len, void *data);
 int mtp_progress (uint64_t const sent, uint64_t const total, void const * const data);
 
+struct _ProgressParams {
+  BOOL *downloadingListing;
+  BOOL *cancelCurrentTransaction;
+};
+typedef struct _ProgressParams ProgressParams;
+
 @end
