@@ -446,6 +446,9 @@ StatusDisplayer *statusDisplayerGlobal;
 
 - (NSString *)ownerString
 {
+  if (![self isConnected])
+		return nil;
+    
 	if (!mtpDevice)
 	{
 		char *ownerString = NJB_Get_Owner_String(njb);
@@ -1900,11 +1903,7 @@ int mtp_progress(uint64_t const sent, uint64_t const total, void const * const d
 			NSLog(@"Could not get battery level property value");
 			return 0;
 		}
-    else
-    {
-      NSLog(@"Got battery level property value");
-    }
-				
+    				
 		return value;
 	}
 }
