@@ -257,6 +257,8 @@
 	[[njbQueue lock] lock];
 	while (queueItem = [enumerator nextObject])
 	{
+    if ([queueItem status] == ITEM_STATUS_RUNNING)
+      [theNJB cancelCurrentTransaction];
 		[queueItem cancel];
 	}
 	[[njbQueue lock] unlockWithCondition:([[njbQueue queue] isEmpty] ? NO_QUEUE_ITEMS : SOME_QUEUE_ITEMS)];
@@ -278,7 +280,7 @@
 	{
 		queueItem = [queueItems objectAtIndex:[index unsignedIntValue]];
 		
-		if ([queueItem status] == ITEM_STATUS_QUEUED)
+		if ([queueItem status] == ITEM_STATUS_QUEUED || [queueItem status] == ITEM_STATUS_RUNNING)
 			[itemsToCancel addObject:queueItem];
 	}
 	NSArray *items = [NSArray arrayWithArray:itemsToCancel];
