@@ -6,17 +6,8 @@
 //  Copyright (c) 2003 __MyCompanyName__. All rights reserved.
 //
 
-#ifdef __APPPLE__
 #import <Foundation/Foundation.h>
 #import "id3V2Frame.h"
-#else
-#ifndef _ID3FRAMEWORK_V24FRAMESET_H_
-#define _ID3FRAMEWORK_V24FRAMESET_H_
-#include <Foundation/NSObject.h>
-#include "id3V2Frame.h"
-@class NSMutableDictionary;
-#endif
-#endif
 
 #define MAXUNCOMPRESSEDFRAMESIZE 10000000
 
