@@ -5,23 +5,10 @@
 //  Created by Chris Drew on Sat Dec 07 2002.
 //  Copyright (c) 2002 __MyCompanyName__. All rights reserved.
 //
-#ifdef __APPLE__
+
 #import "id3V2Frame.h"
 #import <zlib.h>
 #import <AppKit/NSBitmapImageRep.h>
-#else
-
-#ifndef _ID3FRAMEWORK_TAGAPI_H_
-#include "id3V2Frame.h"
-#include <zlib.h>
-#include <Foundation/NSArray.h>
-#include <Foundation/NSCharacterSet.h>
-#include <Foundation/NSData.h>
-#include <Foundation/NSDictionary.h>
-#include <Foundation/NSString.h>
-#include <AppKit/NSBitmapImageRep.h>
-#endif
-#endif
 
 #define kTrimSetStr	@"%c%@", '\0', @" \r\n\t", @"\0\0"
 
