@@ -6,29 +6,12 @@
 //  Copyright (c) 2002 __MyCompanyName__. All rights reserved.
 //
 
-#ifdef __APPLE__
 #import "id3V2Tag.h"
 #import "zlib.h"
 #import <AppKit/NSImage.h>
 #import "V20FrameSet.h"
 #import "V23FrameSet.h"
 #import "V24FrameSet.h"
-#else
-#include "id3V2Tag.h"
-#include "zlib.h"
-#include "V20FrameSet.h"
-#include "V23FrameSet.h"
-#include "V24FrameSet.h"
-
-#include <Foundation/NSArray.h>
-#include <Foundation/NSAutoreleasePool.h>
-#include <Foundation/NSData.h>
-#include <Foundation/NSFileHandle.h>
-#include <Foundation/NSFileManager.h>
-
-#include <AppKit/NSImage.h>
-#endif
-
 
 @implementation id3V2Tag
 
