@@ -28,7 +28,8 @@
 #ifndef LIBMTP_H_INCLUSION_GUARD
 #define LIBMTP_H_INCLUSION_GUARD
 
-#define LIBMTP_VERSION 0.2.0
+#define LIBMTP_VERSION 0.2.2
+#define LIBMTP_VERSION_STRING "0.2.2"
 
 /* This handles MSVC pecularities */
 #ifdef _MSC_VER
@@ -119,7 +120,8 @@ typedef enum {
   LIBMTP_ERROR_MEMORY_ALLOCATION,
   LIBMTP_ERROR_NO_DEVICE_ATTACHED,
   LIBMTP_ERROR_STORAGE_FULL,
-  LIBMTP_ERROR_CONNECTING
+  LIBMTP_ERROR_CONNECTING,
+  LIBMTP_ERROR_CANCELLED
 } LIBMTP_error_number_t;
 typedef struct LIBMTP_device_entry_struct LIBMTP_device_entry_t; /**< @see LIBMTP_device_entry_struct */
 typedef struct LIBMTP_error_struct LIBMTP_error_t; /**< @see LIBMTP_error_struct */
@@ -156,8 +158,9 @@ typedef int (* LIBMTP_progressfunc_t) (uint64_t const sent, uint64_t const total
  * A data structure to hold MTP device entries.
  */
 struct LIBMTP_device_entry_struct {
-  char *name; /**< The descriptive name of this device */
+  char *vendor; /**< The vendor of this device */
   uint16_t vendor_id; /**< Vendor ID for this device */
+  char *product; /**< The product name of this device */
   uint16_t product_id; /**< Product ID for this device */
   uint32_t device_flags; /**< Bugs, device specifics etc */
 };
@@ -175,8 +178,10 @@ struct LIBMTP_error_struct {
  * Main MTP device object struct
  */
 struct LIBMTP_mtpdevice_struct {
-  /** Interface number of this device */
-  uint8_t interface_number;
+  /**
+   * Object bitsize, typically 32 or 64.
+   */
+  uint8_t object_bitsize;
   /**
    * Parameters for this device, must be cast into
    * \c (PTPParams*) before internal use.
